# -*- coding: utf-8 -*-
# Copyright 2023 Cohesity Inc.

class AlertTypeBucketEnum(object):

    """Implementation of the 'AlertTypeBucket' enum.
    Specifies the Alert type bucket. Specifies the Alert type bucket. kHardware
    - Alerts related to hardware on which Cohesity software is running.
    kSoftware - Alerts which are related to software components. kDataService -
    Alerts related to data services. kMaintenance - Alerts relates to
    maintenance activities.


    Attributes:
        KHARDWARE: TODO: type description here.
        KSOFTWARE: TODO: type description here.
        KDATASERVICE: TODO: type description here.
        KMAINTENANCE: TODO: type description here.

    """

    KHARDWARE = 'kHardware'

    KSOFTWARE = 'kSoftware'

    KDATASERVICE = 'kDataService'

    KMAINTENANCE = 'kMaintenance'
